Class: Sink::Models::WriteOnlyResponseSimpleResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sink/models/write_only_response_simple_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#[], #deconstruct_keys, #inspect, #to_h, #to_s

Constructor Details

#initialize(data = {}) ⇒ WriteOnlyResponseSimpleResponse

Create a new instance of WriteOnlyResponseSimpleResponse from a Hash of raw data.

Parameters:

  • data (Hash{Symbol => Object}) (defaults to: {}) —

    . @option data [String, nil] :should_never_show_up This should never be generated as it is a writeOnly property used in a response type.



7
# File 'lib/sink/models/write_only_response_simple_response.rb', line 7

def initialize(data = {}) = super

Instance Attribute Details

#should_never_show_up ⇒ String

This should never be generated as it is a writeOnly property used in a response type.

Returns:

  • (String)


9
# File 'lib/sink/models/write_only_response_simple_response.rb', line 9

optional :should_never_show_up, String, :w