Class: Sink::Resources::ConfigTools::ParentWithSkipNodePython

Inherits:
Object
  • Object
show all
Defined in:
lib/sink/resources/config_tools/parent_with_skip_node_python.rb,
lib/sink/resources/config_tools/parent_with_skip_node_python/child_only_skip_python.rb

Defined Under Namespace

Classes: ChildOnlySkipPython

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ ParentWithSkipNodePython

Returns a new instance of ParentWithSkipNodePython.

Parameters:



11
12
13
14
# File 'lib/sink/resources/config_tools/parent_with_skip_node_python.rb', line 11

def initialize(client:)
  @client = client
  @child_only_skip_python = Sink::Resources::ConfigTools::ParentWithSkipNodePython::ChildOnlySkipPython.new(client: client)
end

Instance Attribute Details

#child_only_skip_python ⇒ Sink::Resources::ConfigTools::ParentWithSkipNodePython::ChildOnlySkipPython (readonly)



8
9
10
# File 'lib/sink/resources/config_tools/parent_with_skip_node_python.rb', line 8

def child_only_skip_python
  @child_only_skip_python
end

Instance Method Details

#not_in_node_python(params = {}, opts = {}) ⇒ Sink::Models::Card

Create a new virtual or physical card. Parameters pin, shippingAddress, and product_id only apply to physical cards.

Parameters:

  • params (Hash{Symbol => Object}) (defaults to: {}) —

    Attributes to send in this request. @option params [Symbol, Type] :type Card types:

    - `MERCHANT_LOCKED` - Card is locked to first merchant that successfully
    authorizes the card.
    - `PHYSICAL` - Manufactured and sent to the cardholder. We offer white label
    branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality.
    Reach out at [lithic.com/contact](https://lithic.com/contact) for more
    information.
    - `SINGLE_USE` - Card will close shortly after the first transaction.
    - `VIRTUAL` - Card will authorize at any merchant and can be added to a digital
    wallet like Apple Pay or Google Pay (if the card program is digital
    wallet-enabled).
    

    @option params [String, nil] :account_token Only required for multi-account users. Token identifying the account the card will be associated with. Only applicable if using account holder enrollment. See Managing Your Program for more information. @option params [String, nil] :card_program_token Identifies the card program under which to create the card. Different card programs may have their own configurations (e.g., digital wallet card art, BIN type). This must be configured with Lithic before use. @option params [String, nil] :exp_month Two digit (MM) expiry month. If neither exp_month nor exp_year is provided, an expiration date will be generated. @option params [String, nil] :exp_year Four digit (yyyy) expiry year. If neither exp_month nor exp_year is provided, an expiration date will be generated. @option params [String, nil] :funding_token The token for the desired FundingAccount to use when making transactions with this card. @option params [String, nil] :memo Friendly name to identify the card. @option params [String, nil] :not_ Used to test the PythonSDKs ability to handle reserved keywords as parameters @option params [String, nil] :pin Encrypted PIN block (in base64). Only applies to cards of type PHYSICAL and VIRTUAL. See Encrypted PIN Block. @option params [String, nil] :product_id Specifies the configuration (e.g., physical card art) that the card should be manufactured with, and only applies to cards of type PHYSICAL [beta]. This must be configured with Lithic before use. @option params [Symbol, ShippingMethod, nil] :shipping_method Shipping method for the card. Only applies to cards of type PHYSICAL [beta]. Use of options besides STANDARD require additional permissions.

    - `STANDARD` - USPS regular mail or similar international option, with no
    tracking
    - `STANDARD_WITH_TRACKING` - USPS regular mail or similar international option,
    with tracking
    - `EXPEDITED` - FedEx Standard Overnight or similar international option, with
    tracking
    

    @option params [Sink::Models::ShippingAddress, nil] :shipping_address @option params [Integer, nil] :spend_limit Amount (in cents) to limit approved authorizations. Transaction requests above the spend limit will be declined. @option params [Symbol, SpendLimitDuration, nil] :spend_limit_duration Spend limit duration values:

    - `ANNUALLY` - Card will authorize transactions up to spend limit in a calendar
    year.
    - `FOREVER` - Card will authorize only up to spend limit for the entire lifetime
    of the card.
    - `MONTHLY` - Card will authorize transactions up to spend limit for the
    trailing month. Month is calculated as this calendar date one month prior.
    - `TRANSACTION` - Card will authorizate multiple transactions if each individual
    transaction is under the spend limit.
    

    @option params [Symbol, State, nil] :state Card state values:

    - `OPEN` - Card will approve authorizations (if they match card and account
    parameters).
    - `PAUSED` - Card will decline authorizations, but can be resumed at a later
    time.
  • opts (Hash, Sink::RequestOptions) (defaults to: {}) —

    Options to specify HTTP behaviour for this request.

Returns:



88
89
90
91
92
93
94
95
96
97
# File 'lib/sink/resources/config_tools/parent_with_skip_node_python.rb', line 88

def not_in_node_python(params = {}, opts = {})
  req = {
    method: :post,
    path: "/cards",
    body: params,
    headers: {"Content-Type" => "application/json"},
    model: Sink::Models::Card
  }
  @client.request(req, opts)
end